@@ -15,13 +15,14 @@
 
 #include "k3boggvorbisencoder.h"
 #include "k3boggvorbisencoderdefaults.h"
+#include "k3bcore.h"
+#include "k3bplugin_i18n.h"
 #include <config-k3b.h>
 
-#include "k3bcore.h"
+#include <KConfigCore/KConfig>
+#include <KConfigCore/KSharedConfig>
 
-#include <KConfig>
-#include <KDebug>
-#include <KLocale>
+#include <QtCore/QDebug>
 
 #include <vorbis/vorbisenc.h>
 
@@ -30,6 +31,8 @@
 #include <time.h>
 
 
+K3B_EXPORT_PLUGIN(k3boggvorbisdecoder, K3bOggVorbisEncoder)
+
 // quality levels -1 to 10 map to 0 to 11
 static const int s_rough_average_quality_level_bitrates[] = {
     45,
@@ -139,7 +142,7 @@ bool K3bOggVorbisEncoder::initEncoderInternal( const QString&, const K3b::Msf& /
     int ret = 0;
 
     if( d->manualBitrate ) {
-        kDebug() << "(K3bOggVorbisEncoder) calling: "
+        qDebug() << "(K3bOggVorbisEncoder) calling: "
                  << "vorbis_encode_init( d->vorbisInfo, 2, 44100, "
                  << (d->bitrateUpper != -1 ? d->bitrateUpper*1000 : -1) << ", "
                  << (d->bitrateNominal != -1 ? d->bitrateNominal*1000 : -1)  << ", "
@@ -158,7 +161,7 @@ bool K3bOggVorbisEncoder::initEncoderInternal( const QString&, const K3b::Msf& /
         else if( d->qualityLevel > 10 )
             d->qualityLevel = 10;
 
-        kDebug() << "(K3bOggVorbisEncoder) calling: "
+        qDebug() << "(K3bOggVorbisEncoder) calling: "
                  << "vorbis_encode_init_vbr( d->vorbisInfo, 2, 44100, "
                  << (float)d->qualityLevel/10.0 << ");" << endl;
 
@@ -169,7 +172,7 @@ bool K3bOggVorbisEncoder::initEncoderInternal( const QString&, const K3b::Msf& /
     }
 
     if( ret ) {
-        kDebug() << "(K3bOggVorbisEncoder) vorbis_encode_init failed: " << ret;
+        qDebug() << "(K3bOggVorbisEncoder) vorbis_encode_init failed: " << ret;
         cleanup();
         return false;
     }
@@ -193,7 +196,7 @@ bool K3bOggVorbisEncoder::initEncoderInternal( const QString&, const K3b::Msf& /
     d->oggStream = new ogg_stream_state;
     srand( time(0) );
     ogg_stream_init( d->oggStream, rand() );
-    
+
     // Set meta data
     for( MetaData::const_iterator it = metaData.constBegin(); it != metaData.constEnd(); ++it ) {
         QByteArray key;
@@ -236,11 +239,11 @@ bool K3bOggVorbisEncoder::initEncoderInternal( const QString&, const K3b::Msf& /
 bool K3bOggVorbisEncoder::writeOggHeaders()
 {
     if( !d->oggStream ) {
-        kDebug() << "(K3bOggVorbisEncoder) call to writeOggHeaders without init.";
+        qDebug() << "(K3bOggVorbisEncoder) call to writeOggHeaders without init.";
         return false;
     }
     if( d->headersWritten ) {
-        kDebug() << "(K3bOggVorbisEncoder) headers already written.";
+        qDebug() << "(K3bOggVorbisEncoder) headers already written.";
         return true;
     }
 
@@ -283,7 +286,7 @@ bool K3bOggVorbisEncoder::writeOggHeaders()
 }
 
 
-long K3bOggVorbisEncoder::encodeInternal( const char* data, Q_ULONG len )
+qint64 K3bOggVorbisEncoder::encodeInternal( const char* data, qint64 len )
 {
     if( !d->headersWritten )
         if( !writeOggHeaders() )
@@ -293,7 +296,7 @@ long K3bOggVorbisEncoder::encodeInternal( const char* data, Q_ULONG len )
     float** buffer = vorbis_analysis_buffer( d->vorbisDspState, len/4 );
 
     // uninterleave samples
-    unsigned long i = 0;
+    qint64 i = 0;
     for( i = 0; i < len/4; i++ ) {
         buffer[0][i]=( (data[i*4+1]<<8) | (0x00ff&(int)data[i*4]) ) / 32768.f;
         buffer[1][i]=( (data[i*4+3]<<8) | (0x00ff&(int)data[i*4+2]) ) / 32768.f;
@@ -344,7 +347,7 @@ void K3bOggVorbisEncoder::finishEncoderInternal()
         flushVorbis();
     }
     else
-        kDebug() << "(K3bOggVorbisEncoder) call to finishEncoderInternal without init.";
+        qDebug() << "(K3bOggVorbisEncoder) call to finishEncoderInternal without init.";
 }
 
 
@@ -393,7 +396,7 @@ void K3bOggVorbisEncoder::cleanup()
 
 void K3bOggVorbisEncoder::loadConfig()
 {
-    KSharedConfig::Ptr c = KGlobal::config();
+    KSharedConfig::Ptr c = KSharedConfig::openConfig();
     KConfigGroup grp(c, "K3bOggVorbisEncoderPlugin" );
 
     d->manualBitrate = grp.readEntry( "manual bitrate", DEFAULT_MANUAL_BITRATE );
@@ -413,7 +416,7 @@ QString K3bOggVorbisEncoder::fileTypeComment( const QString& ) const
 
 long long K3bOggVorbisEncoder::fileSize( const QString&, const K3b::Msf& msf ) const
 {
-    KSharedConfig::Ptr c = KGlobal::config();
+    KSharedConfig::Ptr c = KSharedConfig::openConfig();
     KConfigGroup grp(c, "K3bOggVorbisEncoderPlugin" );
 
     // the following code is based on the size estimation from the audiocd kioslave
